@@ -1,6 +1,6 @@
 """Expose a node."""
 import graphviz as _graphviz
-from systems.hornet import state as _state
+from hornet import state as _state
 
 
 class Node:
